@@ -24,7 +24,7 @@ from app_utils.views import (
 
 from ..app_settings import STRUCTURES_SHOW_FUEL_EXPIRES_RELATIVE
 from ..constants import EveTypeId
-from ..models import Structure, StructureItem, StructureService
+from ..models import EveSpaceType, Structure, StructureItem, StructureService
 
 
 class _AbstractStructureListSerializer(ABC):
@@ -84,13 +84,13 @@ class _AbstractStructureListSerializer(ABC):
         solar_system = structure.eve_solar_system
 
         # location
-        row["region_name"] = solar_system.eve_constellation.eve_region.name_localized
-        row["solar_system_name"] = solar_system.name_localized
+        row["region_name"] = solar_system.eve_constellation.eve_region.name
+        row["solar_system_name"] = solar_system.name
         solar_system_url = dotlan.solar_system_url(solar_system.name)
         if structure.eve_moon:
-            location_name = structure.eve_moon.name_localized
+            location_name = structure.eve_moon.name
         elif structure.eve_planet:
-            location_name = structure.eve_planet.name_localized
+            location_name = structure.eve_planet.name
         else:
             location_name = row["solar_system_name"]
         row["location"] = format_html(
@@ -104,10 +104,10 @@ class _AbstractStructureListSerializer(ABC):
         structure_type = structure.eve_type
         # category
         my_group = structure_type.eve_group
-        row["group_name"] = my_group.name_localized
+        row["group_name"] = my_group.name
         try:
             my_category = my_group.eve_category
-            row["category_name"] = my_category.name_localized
+            row["category_name"] = my_category.name
             row["is_starbase"] = structure.is_starbase
         except AttributeError:
             row["category_name"] = ""
@@ -120,7 +120,7 @@ class _AbstractStructureListSerializer(ABC):
             self.ICON_OUTPUT_SIZE,
         )
         # type name
-        row["type_name"] = structure_type.name_localized
+        row["type_name"] = structure_type.name
         row["type"] = format_html(
             "{}<br><em>{}</em>",
             no_wrap_html(link_html(structure_type.profile_url, row["type_name"])),
@@ -143,7 +143,7 @@ class _AbstractStructureListSerializer(ABC):
         services = list()
         for service in structure.services.all():
             service_name_html = no_wrap_html(
-                format_html("<small>{}</small>", service.name_localized)
+                format_html("<small>{}</small>", service.name)
             )
             if service.state == StructureService.State.OFFLINE:
                 service_name_html = format_html("<del>{}</del>", service_name_html)
@@ -430,15 +430,14 @@ class PocoListSerializer(_AbstractStructureListSerializer):
             space_badge_type = "success"
         else:
             space_badge_type = "danger"
+        space_type = EveSpaceType.from_solar_system(structure.eve_solar_system)
         solar_system_html = format_html(
             "{}<br>{}",
             link_html(
                 dotlan.solar_system_url(structure.eve_solar_system.name),
                 structure.eve_solar_system.name,
             ),
-            bootstrap_label_html(
-                text=structure.eve_solar_system.space_type, label=space_badge_type
-            ),
+            bootstrap_label_html(text=space_type.value, label=space_badge_type),
         )
         row["solar_system_html"] = {
             "display": solar_system_html,
@@ -446,7 +445,7 @@ class PocoListSerializer(_AbstractStructureListSerializer):
         }
         row["solar_system"] = structure.eve_solar_system.name
         row["region"] = structure.eve_solar_system.eve_constellation.eve_region.name
-        row["space_type"] = structure.eve_solar_system.space_type
+        row["space_type"] = space_type.value
 
     def _add_planet(self, structure, row):
         try:
